@@ -65,6 +65,8 @@ data_cfg = dict(
 
 train_pipeline = [
     dict(type='LoadImageFromFile'),
+    dict(type='TopDownGetBboxCenterScale', padding=1.25),
+    dict(type='TopDownRandomShiftBboxCenter', shift_factor=0.16, prob=0.3),
     dict(type='TopDownRandomFlip', flip_prob=0.5),
     dict(
         type='TopDownGetRandomScaleRotation', rot_factor=30,
@@ -87,6 +89,7 @@ train_pipeline = [
 
 val_pipeline = [
     dict(type='LoadImageFromFile'),
+    dict(type='TopDownGetBboxCenterScale', padding=1.25),
     dict(type='TopDownAffine'),
     dict(type='ToTensor'),
     dict(
@@ -114,21 +117,21 @@ data = dict(
     test_dataloader=dict(samples_per_gpu=32),
     train=dict(
         type='TopDownJhmdbDataset',
-        ann_file=f'{data_root}/annotations/Sub2_train.json',
+        ann_file=f'{data_root}/annotations/Sub3_train.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
         pipeline=train_pipeline,
         dataset_info={{_base_.dataset_info}}),
     val=dict(
         type='TopDownJhmdbDataset',
-        ann_file=f'{data_root}/annotations/Sub2_test.json',
+        ann_file=f'{data_root}/annotations/Sub3_test.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
         pipeline=val_pipeline,
         dataset_info={{_base_.dataset_info}}),
     test=dict(
         type='TopDownJhmdbDataset',
-        ann_file=f'{data_root}/annotations/Sub2_test.json',
+        ann_file=f'{data_root}/annotations/Sub3_test.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
         pipeline=test_pipeline,
