@@ -1,5 +1,9 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .dist_utils import allreduce_grads, sync_random_seed
+from .model_util_hooks import ModelSetEpochHook
 from .regularizations import WeightNormClipHook
 
-__all__ = ['allreduce_grads', 'WeightNormClipHook', 'sync_random_seed']
+__all__ = [
+    'allreduce_grads', 'WeightNormClipHook', 'sync_random_seed',
+    'ModelSetEpochHook'
+]
