@@ -1,10 +1,11 @@
 # Copyright (c) OpenMMLab. All rights reserved.
-import os
+import os.path as osp
+import tempfile
 import warnings
 from collections import OrderedDict
 
 import numpy as np
-from mmcv import Config
+from mmcv import Config, deprecated_api_warning
 
 from ...builder import DATASETS
 from ..base import Kpt2dSviewRgbImgTopDownDataset
@@ -107,16 +108,10 @@ class AnimalHorse10Dataset(Kpt2dSviewRgbImgTopDownDataset):
                 joints_3d[:, :2] = keypoints[:, :2]
                 joints_3d_visible[:, :2] = np.minimum(1, keypoints[:, 2:3])
 
-                # use 1.25 padded bbox as input
-                center, scale = self._xywh2cs(*obj['bbox'][:4], 1.25)
-
-                image_file = os.path.join(self.img_prefix,
-                                          self.id2name[img_id])
+                image_file = osp.join(self.img_prefix, self.id2name[img_id])
 
                 gt_db.append({
                     'image_file': image_file,
-                    'center': center,
-                    'scale': scale,
                     'rotation': 0,
                     'joints_3d': joints_3d,
                     'joints_3d_visible': joints_3d_visible,
@@ -145,7 +140,8 @@ class AnimalHorse10Dataset(Kpt2dSviewRgbImgTopDownDataset):
             gts[:, 0, :] - gts[:, 1, :], axis=1, keepdims=True)
         return np.tile(interocular, [1, 2])
 
-    def evaluate(self, outputs, res_folder, metric='PCK', **kwargs):
+    @deprecated_api_warning(name_dict=dict(outputs='results'))
+    def evaluate(self, results, res_folder=None, metric='PCK', **kwargs):
         """Evaluate horse-10 keypoint results. The pose prediction results will
         be saved in ``${res_folder}/result_keypoints.json``.
 
@@ -156,7 +152,8 @@ class AnimalHorse10Dataset(Kpt2dSviewRgbImgTopDownDataset):
             - heatmap width: W
 
         Args:
-            outputs (list[dict]): Outputs containing the following items.
+            results (list[dict]): Testing results containing the following
+                items:
 
                 - preds (np.ndarray[N,K,3]): The first two dimensions are \
                     coordinates, score is the third dimension of the array.
@@ -164,7 +161,9 @@ class AnimalHorse10Dataset(Kpt2dSviewRgbImgTopDownDataset):
                     scale[1],area, score]
                 - image_paths (list[str]): For example, ['Test/source/0.jpg']
                 - output_heatmap (np.ndarray[N, K, H, W]): model outputs.
-            res_folder (str): Path of directory to save the results.
+            res_folder (str, optional): The folder to save the testing
+                results. If not specified, a temp folder will be created.
+                Default: None.
             metric (str | list[str]): Metric to be performed.
                 Options: 'PCK', 'NME'.
 
@@ -177,14 +176,19 @@ class AnimalHorse10Dataset(Kpt2dSviewRgbImgTopDownDataset):
             if metric not in allowed_metrics:
                 raise KeyError(f'metric {metric} is not supported')
 
-        res_file = os.path.join(res_folder, 'result_keypoints.json')
+        if res_folder is not None:
+            tmp_folder = None
+            res_file = osp.join(res_folder, 'result_keypoints.json')
+        else:
+            tmp_folder = tempfile.TemporaryDirectory()
+            res_file = osp.join(tmp_folder.name, 'result_keypoints.json')
 
         kpts = []
-        for output in outputs:
-            preds = output['preds']
-            boxes = output['boxes']
-            image_paths = output['image_paths']
-            bbox_ids = output['bbox_ids']
+        for result in results:
+            preds = result['preds']
+            boxes = result['boxes']
+            image_paths = result['image_paths']
+            bbox_ids = result['bbox_ids']
 
             batch_size = len(image_paths)
             for i in range(batch_size):
@@ -205,4 +209,7 @@ class AnimalHorse10Dataset(Kpt2dSviewRgbImgTopDownDataset):
         info_str = self._report_metric(res_file, metrics)
         name_value = OrderedDict(info_str)
 
+        if tmp_folder is not None:
+            tmp_folder.cleanup()
+
         return name_value
