@@ -1,10 +1,11 @@
 # Copyright (c) OpenMMLab. All rights reserved.
-import os
+import os.path as osp
+import tempfile
 import warnings
 from collections import OrderedDict
 
 import numpy as np
-from mmcv import Config
+from mmcv import Config, deprecated_api_warning
 
 from mmpose.datasets.builder import DATASETS
 from ..base import Kpt2dSviewRgbImgTopDownDataset
@@ -83,14 +84,10 @@ class Face300WDataset(Kpt2dSviewRgbImgTopDownDataset):
                 joints_3d[:, :2] = keypoints[:, :2]
                 joints_3d_visible[:, :2] = np.minimum(1, keypoints[:, 2:3])
 
-                if 'center' in obj and 'scale' in obj:
-                    center = np.array(obj['center'])
-                    scale = np.array([obj['scale'], obj['scale']]) * 1.25
-                else:
-                    center, scale = self._xywh2cs(*obj['bbox'][:4], 1.25)
+                center = np.array(obj['center'])
+                scale = np.array([obj['scale'], obj['scale']])
 
-                image_file = os.path.join(self.img_prefix,
-                                          self.id2name[img_id])
+                image_file = osp.join(self.img_prefix, self.id2name[img_id])
                 gt_db.append({
                     'image_file': image_file,
                     'center': center,
@@ -123,7 +120,8 @@ class Face300WDataset(Kpt2dSviewRgbImgTopDownDataset):
             gts[:, 36, :] - gts[:, 45, :], axis=1, keepdims=True)
         return np.tile(interocular, [1, 2])
 
-    def evaluate(self, outputs, res_folder, metric='NME', **kwargs):
+    @deprecated_api_warning(name_dict=dict(outputs='results'))
+    def evaluate(self, results, res_folder=None, metric='NME', **kwargs):
         """Evaluate freihand keypoint results. The pose prediction results will
         be saved in ``${res_folder}/result_keypoints.json``.
 
@@ -134,7 +132,8 @@ class Face300WDataset(Kpt2dSviewRgbImgTopDownDataset):
             - heatmap width: W
 
         Args:
-            outputs (list[dict]): Outputs containing the following items.
+            results (list[dict]): Testing results containing the following
+                items:
 
                 - preds (np.ndarray[1,K,3]): The first two dimensions are \
                     coordinates, score is the third dimension of the array.
@@ -143,7 +142,9 @@ class Face300WDataset(Kpt2dSviewRgbImgTopDownDataset):
                 - image_path (list[str]): For example, ['300W/ibug/\
                     image_018.jpg']
                 - output_heatmap (np.ndarray[N, K, H, W]): model outputs.
-            res_folder (str): Path of directory to save the results.
+            res_folder (str, optional): The folder to save the testing
+                results. If not specified, a temp folder will be created.
+                Default: None.
             metric (str | list[str]): Metric to be performed.
                 Options: 'NME'.
 
@@ -156,14 +157,19 @@ class Face300WDataset(Kpt2dSviewRgbImgTopDownDataset):
             if metric not in allowed_metrics:
                 raise KeyError(f'metric {metric} is not supported')
 
-        res_file = os.path.join(res_folder, 'result_keypoints.json')
+        if res_folder is not None:
+            tmp_folder = None
+            res_file = osp.join(res_folder, 'result_keypoints.json')
+        else:
+            tmp_folder = tempfile.TemporaryDirectory()
+            res_file = osp.join(tmp_folder.name, 'result_keypoints.json')
 
         kpts = []
-        for output in outputs:
-            preds = output['preds']
-            boxes = output['boxes']
-            image_paths = output['image_paths']
-            bbox_ids = output['bbox_ids']
+        for result in results:
+            preds = result['preds']
+            boxes = result['boxes']
+            image_paths = result['image_paths']
+            bbox_ids = result['bbox_ids']
 
             batch_size = len(image_paths)
             for i in range(batch_size):
@@ -184,4 +190,7 @@ class Face300WDataset(Kpt2dSviewRgbImgTopDownDataset):
         info_str = self._report_metric(res_file, metrics)
         name_value = OrderedDict(info_str)
 
+        if tmp_folder is not None:
+            tmp_folder.cleanup()
+
         return name_value
