@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import numpy as np
 from torch.utils.data import Dataset
 
@@ -36,7 +37,7 @@ class MeshAdversarialDataset(Dataset):
         """
         data = self.train_dataset[i]
         ind_adv = np.random.randint(
-            low=0, high=len(self.adversarial_dataset), dtype=np.int)
+            low=0, high=len(self.adversarial_dataset), dtype=int)
         data.update(self.adversarial_dataset[ind_adv %
                                              len(self.adversarial_dataset)])
         return data
