@@ -86,8 +86,8 @@ class PoseLifter(BasePose):
         if self.semi:
             assert keypoint_head is not None and traj_head is not None
             self.loss_semi = builder.build_loss(loss_semi)
-
-        self.init_weights(pretrained=pretrained)
+        self.pretrained = pretrained
+        self.init_weights()
 
     @property
     def with_neck(self):
@@ -125,13 +125,15 @@ class PoseLifter(BasePose):
 
     def init_weights(self, pretrained=None):
         """Weight initialization for model."""
-        self.backbone.init_weights(pretrained)
+        if pretrained is not None:
+            self.pretrained = pretrained
+        self.backbone.init_weights(self.pretrained)
         if self.with_neck:
             self.neck.init_weights()
         if self.with_keypoint:
             self.keypoint_head.init_weights()
         if self.with_traj_backbone:
-            self.traj_backbone.init_weights(pretrained)
+            self.traj_backbone.init_weights(self.pretrained)
         if self.with_traj_neck:
             self.traj_neck.init_weights()
         if self.with_traj:
@@ -149,16 +151,13 @@ class PoseLifter(BasePose):
         return_loss=True.
 
         Note:
-            Note:
-            batch_size: N
-            num_input_keypoints: Ki
-            input_keypoint_dim: Ci
-            input_sequence_len: Ti
-            num_output_keypoints: Ko
-            output_keypoint_dim: Co
-            input_sequence_len: To
-
-
+            - batch_size: N
+            - num_input_keypoints: Ki
+            - input_keypoint_dim: Ci
+            - input_sequence_len: Ti
+            - num_output_keypoints: Ko
+            - output_keypoint_dim: Co
+            - input_sequence_len: To
 
         Args:
             input (torch.Tensor[NxKixCixTi]): Input keypoint coordinates.
@@ -169,9 +168,10 @@ class PoseLifter(BasePose):
             metas (list(dict)): Information about data augmentation
             return_loss (bool): Option to `return loss`. `return loss=True`
                 for training, `return loss=False` for validation & test.
+
         Returns:
-            dict|Tensor: if `reutrn_loss` is true, return losses. Otherwise
-                return predicted poses
+            dict|Tensor: If `reutrn_loss` is true, return losses. \
+                Otherwise return predicted poses.
         """
         if return_loss:
             return self.forward_train(input, target, target_weight, metas,
@@ -304,6 +304,7 @@ class PoseLifter(BasePose):
 
         Args:
             result (list[dict]): The pose estimation results containing:
+
                 - "keypoints_3d" ([K,4]): 3D keypoints
                 - "keypoints" ([K,3] or [T,K,3]): Optional for visualizing
                     2D inputs. If a sequence is given, only the last frame
@@ -319,7 +320,7 @@ class PoseLifter(BasePose):
                 If None, do not draw links.
             radius (int): Radius of circles.
             thickness (int): Thickness of lines.
-            vis_height (int): The image hight of the visualization. The width
+            vis_height (int): The image height of the visualization. The width
                 will be N*vis_height depending on the number of visualized
                 items.
             win_name (str): The window name.
