@@ -13,19 +13,21 @@ from mmpose.models.builder import HEADS, build_loss
 class DeepposeRegressionHead(nn.Module):
     """Deeppose regression head with fully connected layers.
 
-    paper ref: Alexander Toshev and Christian Szegedy,
-    ``DeepPose: Human Pose Estimation via Deep Neural Networks.''.
+    "DeepPose: Human Pose Estimation via Deep Neural Networks".
 
     Args:
         in_channels (int): Number of input channels
         num_joints (int): Number of joints
         loss_keypoint (dict): Config for keypoint loss. Default: None.
+        out_sigma (bool): Predict the sigma (the viriance of the joint
+            location) together with the joint location. Default: False
     """
 
     def __init__(self,
                  in_channels,
                  num_joints,
                  loss_keypoint=None,
+                 out_sigma=False,
                  train_cfg=None,
                  test_cfg=None):
         super().__init__()
@@ -38,23 +40,36 @@ class DeepposeRegressionHead(nn.Module):
         self.train_cfg = {} if train_cfg is None else train_cfg
         self.test_cfg = {} if test_cfg is None else test_cfg
 
-        self.fc = nn.Linear(self.in_channels, self.num_joints * 2)
+        self.out_sigma = out_sigma
+
+        if out_sigma:
+            self.fc = nn.Linear(self.in_channels, self.num_joints * 4)
+        else:
+            self.fc = nn.Linear(self.in_channels, self.num_joints * 2)
 
     def forward(self, x):
         """Forward function."""
+        if isinstance(x, (list, tuple)):
+            assert len(x) == 1, ('DeepPoseRegressionHead only supports '
+                                 'single-level feature.')
+            x = x[0]
+
         output = self.fc(x)
         N, C = output.shape
-        return output.reshape([N, C // 2, 2])
+        if self.out_sigma:
+            return output.reshape([N, C // 4, 4])
+        else:
+            return output.reshape([N, C // 2, 2])
 
     def get_loss(self, output, target, target_weight):
         """Calculate top-down keypoint loss.
 
         Note:
-            batch_size: N
-            num_keypoints: K
+            - batch_size: N
+            - num_keypoints: K
 
         Args:
-            output (torch.Tensor[N, K, 2]): Output keypoints.
+            output (torch.Tensor[N, K, 2 or 4]): Output keypoints.
             target (torch.Tensor[N, K, 2]): Target keypoints.
             target_weight (torch.Tensor[N, K, 2]):
                 Weights across different joint types.
@@ -63,6 +78,7 @@ class DeepposeRegressionHead(nn.Module):
         losses = dict()
         assert not isinstance(self.loss, nn.Sequential)
         assert target.dim() == 3 and target_weight.dim() == 3
+
         losses['reg_loss'] = self.loss(output, target, target_weight)
 
         return losses
@@ -71,11 +87,11 @@ class DeepposeRegressionHead(nn.Module):
         """Calculate accuracy for top-down keypoint loss.
 
         Note:
-            batch_size: N
-            num_keypoints: K
+            - batch_size: N
+            - num_keypoints: K
 
         Args:
-            output (torch.Tensor[N, K, 2]): Output keypoints.
+            output (torch.Tensor[N, K, 2 or 4]): Output keypoints.
             target (torch.Tensor[N, K, 2]): Target keypoints.
             target_weight (torch.Tensor[N, K, 2]):
                 Weights across different joint types.
@@ -84,6 +100,7 @@ class DeepposeRegressionHead(nn.Module):
         accuracy = dict()
 
         N = output.shape[0]
+        output = output[..., :2]
 
         _, avg_acc, cnt = keypoint_pck_accuracy(
             output.detach().cpu().numpy(),
@@ -121,16 +138,18 @@ class DeepposeRegressionHead(nn.Module):
         Args:
             img_metas (list(dict)): Information about data augmentation
                 By default this includes:
+
                 - "image_file: path to the image file
                 - "center": center of the bbox
                 - "scale": scale of the bbox
                 - "rotation": rotation of the bbox
                 - "bbox_score": score of bbox
-            output (np.ndarray[N, K, 2]): predicted regression vector.
+            output (np.ndarray[N, K, >=2]): predicted regression vector.
             kwargs: dict contains 'img_size'.
                 img_size (tuple(img_width, img_height)): input image size.
         """
         batch_size = len(img_metas)
+        output = output[..., :2]  # get prediction joint locations
 
         if 'bbox_id' in img_metas[0]:
             bbox_ids = []
