@@ -32,13 +32,14 @@ class TopdownHeatmapSimpleHead(TopdownHeatmapBaseHead):
         in_index (int|Sequence[int]): Input feature index. Default: 0
         input_transform (str|None): Transformation type of input features.
             Options: 'resize_concat', 'multiple_select', None.
-            'resize_concat': Multiple feature maps will be resized to the
+            Default: None.
+
+            - 'resize_concat': Multiple feature maps will be resized to the
                 same size as the first one and then concat together.
                 Usually used in FCN head of HRNet.
-            'multiple_select': Multiple feature maps will be bundle into
+            - 'multiple_select': Multiple feature maps will be bundle into
                 a list and passed into decode head.
-            None: Only one select feature map is allowed.
-            Default: None.
+            - None: Only one select feature map is allowed.
         align_corners (bool): align_corners argument of F.interpolate.
             Default: False.
         loss_keypoint (dict): Config for keypoint loss. Default: None.
@@ -143,15 +144,15 @@ class TopdownHeatmapSimpleHead(TopdownHeatmapBaseHead):
         """Calculate top-down keypoint loss.
 
         Note:
-            batch_size: N
-            num_keypoints: K
-            heatmaps height: H
-            heatmaps weight: W
+            - batch_size: N
+            - num_keypoints: K
+            - heatmaps height: H
+            - heatmaps weight: W
 
         Args:
-            output (torch.Tensor[NxKxHxW]): Output heatmaps.
-            target (torch.Tensor[NxKxHxW]): Target heatmaps.
-            target_weight (torch.Tensor[NxKx1]):
+            output (torch.Tensor[N,K,H,W]): Output heatmaps.
+            target (torch.Tensor[N,K,H,W]): Target heatmaps.
+            target_weight (torch.Tensor[N,K,1]):
                 Weights across different joint types.
         """
 
@@ -159,7 +160,7 @@ class TopdownHeatmapSimpleHead(TopdownHeatmapBaseHead):
 
         assert not isinstance(self.loss, nn.Sequential)
         assert target.dim() == 4 and target_weight.dim() == 3
-        losses['mse_loss'] = self.loss(output, target, target_weight)
+        losses['heatmap_loss'] = self.loss(output, target, target_weight)
 
         return losses
 
@@ -167,15 +168,15 @@ class TopdownHeatmapSimpleHead(TopdownHeatmapBaseHead):
         """Calculate accuracy for top-down keypoint loss.
 
         Note:
-            batch_size: N
-            num_keypoints: K
-            heatmaps height: H
-            heatmaps weight: W
+            - batch_size: N
+            - num_keypoints: K
+            - heatmaps height: H
+            - heatmaps weight: W
 
         Args:
-            output (torch.Tensor[NxKxHxW]): Output heatmaps.
-            target (torch.Tensor[NxKxHxW]): Target heatmaps.
-            target_weight (torch.Tensor[NxKx1]):
+            output (torch.Tensor[N,K,H,W]): Output heatmaps.
+            target (torch.Tensor[N,K,H,W]): Target heatmaps.
+            target_weight (torch.Tensor[N,K,1]):
                 Weights across different joint types.
         """
 
@@ -204,8 +205,8 @@ class TopdownHeatmapSimpleHead(TopdownHeatmapBaseHead):
             output_heatmap (np.ndarray): Output heatmaps.
 
         Args:
-            x (torch.Tensor[NxKxHxW]): Input features.
-            flip_pairs (None | list[tuple()):
+            x (torch.Tensor[N,K,H,W]): Input features.
+            flip_pairs (None | list[tuple]):
                 Pairs of keypoints which are mirrored.
         """
         output = self.forward(x)
@@ -236,12 +237,13 @@ class TopdownHeatmapSimpleHead(TopdownHeatmapBaseHead):
             in_index (int|Sequence[int]): Input feature index.
             input_transform (str|None): Transformation type of input features.
                 Options: 'resize_concat', 'multiple_select', None.
-                'resize_concat': Multiple feature maps will be resize to the
+
+                - 'resize_concat': Multiple feature maps will be resize to the
                     same size as first one and than concat together.
                     Usually used in FCN head of HRNet.
-                'multiple_select': Multiple feature maps will be bundle into
+                - 'multiple_select': Multiple feature maps will be bundle into
                     a list and passed into decode head.
-                None: Only one select feature map is allowed.
+                - None: Only one select feature map is allowed.
         """
 
         if input_transform is not None:
